@@ -60,7 +60,7 @@ func replayOplog(cn *pbm.PBM, o replayOptions, outf outFormat) (fmt.Stringer, er
 	name := time.Now().UTC().Format(time.RFC3339Nano)
 	cmd := pbm.Cmd{
 		Cmd: pbm.CmdReplay,
-		Replay: pbm.ReplayCmd{
+		Replay: &pbm.ReplayCmd{
 			Name:  name,
 			Start: startTS,
 			End:   endTS,
@@ -80,7 +80,7 @@ func replayOplog(cn *pbm.PBM, o replayOptions, outf outFormat) (fmt.Stringer, er
 	ctx, cancel := context.WithTimeout(context.Background(), pbm.WaitActionStart)
 	defer cancel()
 
-	m, err := waitForRestoreStatus(ctx, cn, name)
+	m, err := waitForRestoreStatus(ctx, cn, name, cn.GetRestoreMeta)
 	if err != nil {
 		return nil, err
 	}
