@@ -4,7 +4,8 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
+	"io"
+	"log"
 	"regexp"
 	"strings"
 	"time"
@@ -111,7 +112,7 @@ type SnapshotStat struct {
 	Size       int64      `json:"size,omitempty"`
 	Status     pbm.Status `json:"status"`
 	Err        string     `json:"error,omitempty"`
-	StateTS    int64      `json:"completeTS"`
+	RestoreTS  int64      `json:"restoreTo"`
 	PBMVersion string     `json:"pbmVersion"`
 }
 
@@ -143,19 +144,6 @@ func skipCtl(str string) []byte {
 	return []byte(str)
 }
 
-func stripCtl(str string) []byte {
-	b := make([]byte, len(str))
-	var bl int
-	for i := 0; i < len(str); i++ {
-		c := str[i]
-		if c >= 32 && c != 127 {
-			b[bl] = c
-			bl++
-		}
-	}
-	return b[:bl]
-}
-
 func (c *Ctl) CheckBackup(bcpName string, waitFor time.Duration) error {
 	tmr := time.NewTimer(waitFor)
 	tkr := time.NewTicker(500 * time.Millisecond)
@@ -189,6 +177,14 @@ func (c *Ctl) CheckBackup(bcpName string, waitFor time.Duration) error {
 }
 
 func (c *Ctl) CheckRestore(bcpName string, waitFor time.Duration) error {
+	type rlist struct {
+		Start    int
+		Status   pbm.Status
+		Type     string
+		Name     string
+		Snapshot string
+		Error    string
+	}
 	tmr := time.NewTimer(waitFor)
 	tkr := time.NewTicker(500 * time.Millisecond)
 	for {
@@ -196,24 +192,38 @@ func (c *Ctl) CheckRestore(bcpName string, waitFor time.Duration) error {
 		case <-tmr.C:
 			list, err := c.RunCmd("pbm", "list", "--restore")
 			if err != nil {
-				return errors.Wrap(err, "timeout reached. get backups list")
+				return errors.Wrap(err, "timeout reached. get restores list")
 			}
-			return errors.Errorf("timeout reached. backups list:\n%s", list)
+			return errors.Errorf("timeout reached. restores list:\n%s", list)
 		case <-tkr.C:
-			out, err := c.RunCmd("pbm", "list", "--restore")
+			out, err := c.RunCmd("pbm", "list", "--restore", "-o", "json")
 			if err != nil {
 				return err
 			}
-			for _, s := range strings.Split(out, "\n") {
-				s := strings.TrimSpace(s)
-				if s == bcpName {
-					return nil
+
+			// trim rubbish from the output
+			i := strings.Index(out, "[")
+			if i == -1 || len(out) <= i {
+				continue
+			}
+			out = out[i:]
+
+			var list []rlist
+			err = json.Unmarshal([]byte(out), &list)
+			if err != nil {
+				log.Printf("\n\n%s\n\n", strings.TrimSpace(out))
+				return errors.Wrap(err, "unmarshal list")
+			}
+			for _, r := range list {
+				if r.Snapshot != bcpName {
+					continue
 				}
-				if strings.HasPrefix(s, bcpName) {
-					status := strings.TrimSpace(strings.Split(s, bcpName)[1])
-					if strings.Contains(status, "Failed with") {
-						return errors.New(status)
-					}
+
+				switch r.Status {
+				case pbm.StatusDone:
+					return nil
+				case pbm.StatusError:
+					errors.Errorf("failed with %s", r.Error)
 				}
 			}
 		}
@@ -221,7 +231,7 @@ func (c *Ctl) CheckRestore(bcpName string, waitFor time.Duration) error {
 }
 
 func (c *Ctl) CheckPITRestore(t time.Time, timeout time.Duration) error {
-	rinlist := "PITR: " + t.Format("2006-01-02T15:04:05Z")
+	rinlist := "restore time: " + t.Format("2006-01-02T15:04:05Z")
 	return c.waitForRestore(rinlist, timeout)
 }
 
@@ -249,15 +259,17 @@ func (c *Ctl) waitForRestore(rinlist string, waitFor time.Duration) error {
 				return err
 			}
 			for _, s := range strings.Split(out, "\n") {
-				s := strings.TrimSpace(s)
-				if s == rinlist {
+				if !strings.Contains(s, rinlist) {
+					continue
+				}
+
+				_, status, _ := strings.Cut(s, "\t")
+				status = strings.TrimSpace(status)
+				if status == "done" {
 					return nil
 				}
-				if strings.HasPrefix(s, rinlist) {
-					status := strings.TrimSpace(strings.Split(s, rinlist)[1])
-					if strings.Contains(status, "Failed with") {
-						return errors.New(status)
-					}
+				if strings.Contains(status, "Failed with") {
+					return errors.New(status)
 				}
 			}
 		}
@@ -331,7 +343,7 @@ func (c *Ctl) RunCmd(cmds ...string) (string, error) {
 				return "", errors.Wrap(err, "ContainerExecInspect")
 			}
 			if !insp.Running {
-				logs, err := ioutil.ReadAll(container.Reader)
+				logs, err := io.ReadAll(container.Reader)
 				if err != nil {
 					return "", errors.Wrap(err, "read logs of failed container")
 				}
@@ -357,7 +369,7 @@ func (c *Ctl) ContainerLogs() (string, error) {
 		return "", errors.Wrap(err, "get logs of failed container")
 	}
 	defer r.Close()
-	logs, err := ioutil.ReadAll(r)
+	logs, err := io.ReadAll(r)
 	if err != nil {
 		return "", errors.Wrap(err, "read logs of failed container")
 	}
