@@ -2,7 +2,6 @@ package sharded
 
 import (
 	"fmt"
-	"io/ioutil"
 	"log"
 	"net/url"
 	"os"
@@ -10,8 +9,9 @@ import (
 	"time"
 
 	"github.com/minio/minio-go"
-	"github.com/percona/percona-backup-mongodb/pbm"
 	"gopkg.in/yaml.v2"
+
+	"github.com/percona/percona-backup-mongodb/pbm"
 )
 
 type backupDelete struct {
@@ -102,7 +102,7 @@ func (c *Cluster) BackupDelete(storage string) {
 		os.Exit(1)
 	}
 
-	tsp := time.Unix(list.Snapshots[len(list.Snapshots)-1].StateTS, 0).Add(time.Second * 10)
+	tsp := time.Unix(list.Snapshots[len(list.Snapshots)-1].RestoreTS, 0).Add(time.Second * 10)
 
 	log.Printf("delete pitr older than %s \n", tsp.Format("2006-01-02T15:04:05"))
 	_, err = c.pbm.RunCmd("pbm", "delete-pitr", "-f", "--older-than", tsp.Format("2006-01-02T15:04:05"))
@@ -127,8 +127,8 @@ func (c *Cluster) BackupDelete(storage string) {
 		log.Fatalf("ERROR: empty spanpshots list")
 	}
 
-	if list.PITR.Ranges[0].Range.Start-1 != uint32(list.Snapshots[len(list.Snapshots)-1].StateTS) {
-		log.Printf("ERROR: expected range starts the next second after the backup complete time, %v | %v", list.PITR.Ranges[0].Range.Start+1, uint32(list.Snapshots[len(list.Snapshots)-1].StateTS))
+	if list.PITR.Ranges[0].Range.Start-1 != uint32(list.Snapshots[len(list.Snapshots)-1].RestoreTS) {
+		log.Printf("ERROR: expected range starts the next second after the backup complete time, %v | %v", list.PITR.Ranges[0].Range.Start+1, uint32(list.Snapshots[len(list.Snapshots)-1].RestoreTS))
 		c.printBcpList()
 		os.Exit(1)
 	}
@@ -167,7 +167,7 @@ const awsurl = "s3.amazonaws.com"
 // except for the shouldStay
 func checkArtefacts(conf string, shouldStay map[string]struct{}) {
 	log.Println("check all artifacts deleted excepts backup's", shouldStay)
-	buf, err := ioutil.ReadFile(conf)
+	buf, err := os.ReadFile(conf)
 	if err != nil {
 		log.Fatalln("ERROR: unable to read config file:", err)
 	}
